@@ -4,8 +4,7 @@
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef THEMEEDITORUTIL_H
-#define THEMEEDITORUTIL_H
+#pragma once
 
 #include <QString>
 
@@ -17,4 +16,3 @@ public:
     Q_REQUIRED_RESULT QString defaultTemplate() const;
 };
 
-#endif // THEMEEDITORUTIL_H
